#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "DES_EDE3","my secret key";
RandomIVa._.Vԍ<2rP_ EjZ4gn|e%O([K[]e|~mY_i0*Ra+?Јk@kQn]D'*TK"z)=%Fo%6